@@ -37,18 +37,18 @@ valid_lightness = [
     # fmt: off
     pytest.param(
         b'\x82\x4b',
-        LightLightnessOpcode.LIGHTNESS_GET,
+        LightLightnessOpcode.LIGHT_LIGHTNESS_GET,
         dict(),
         id="LIGHTNESS_GET"),
     pytest.param(
         b'\x82\x4c\xbb\xaa\x22',
-        LightLightnessOpcode.LIGHTNESS_SET,
+        LightLightnessOpcode.LIGHT_LIGHTNESS_SET,
         dict(lightness=0xaabb,
              tid=34),
         id="LIGHTNESS_SET"),
     pytest.param(
         b'\x82\x4c\x01\x00\x22',
-        LightLightnessOpcode.LIGHTNESS_SET,
+        LightLightnessOpcode.LIGHT_LIGHTNESS_SET,
         dict(lightness=1,
              tid=34,
              transition_time=6.3,
@@ -56,7 +56,7 @@ valid_lightness = [
         id="LIGHTNESS_SET_invalid"),
     pytest.param(
         b'\x82\x4c\x00\x00\x31\x32\x3c',
-        LightLightnessOpcode.LIGHTNESS_SET,
+        LightLightnessOpcode.LIGHT_LIGHTNESS_SET,
         dict(lightness=0,
              tid=49,
              transition_time=5,
@@ -64,7 +64,7 @@ valid_lightness = [
         id="LIGHTNESS_SET_with_optional"),
     pytest.param(
         b'\x82\x4d\x00\x00\x31\x32\x3c',
-        LightLightnessOpcode.LIGHTNESS_SET_UNACKNOWLEDGED,
+        LightLightnessOpcode.LIGHT_LIGHTNESS_SET_UNACKNOWLEDGED,
         dict(lightness=0,
              tid=49,
              transition_time=5,
@@ -72,12 +72,12 @@ valid_lightness = [
         id="LIGHTNESS_SET_UNACKNOWLEDGED"),
     pytest.param(
         b'\x82\x4e\x44\x00',
-        LightLightnessOpcode.LIGHTNESS_STATUS,
+        LightLightnessOpcode.LIGHT_LIGHTNESS_STATUS,
         dict(present_lightness=0x44),
         id="LIGHTNESS_STATUS"),
     pytest.param(
         b'\x82\x4e\x00\x00\x31\xc8\x0f',
-        LightLightnessOpcode.LIGHTNESS_STATUS,
+        LightLightnessOpcode.LIGHT_LIGHTNESS_STATUS,
         dict(present_lightness=0,
              target_lightness=0xc831,
              remaining_time=1.5),
@@ -85,18 +85,18 @@ valid_lightness = [
 
     pytest.param(
         b'\x82\x4f',
-        LightLightnessOpcode.LIGHTNESS_LINEAR_GET,
+        LightLightnessOpcode.LIGHT_LIGHTNESS_LINEAR_GET,
         dict(),
         id="LIGHTNESS_LINEAR_GET"),
     pytest.param(
         b'\x82\x50\xbb\xaa\x01',
-        LightLightnessOpcode.LIGHTNESS_LINEAR_SET,
+        LightLightnessOpcode.LIGHT_LIGHTNESS_LINEAR_SET,
         dict(lightness=0xaabb,
              tid=1),
         id="LIGHTNESS_LINEAR_SET"),
     pytest.param(
         b'\x82\x50\x01\x00\x22',
-        LightLightnessOpcode.LIGHTNESS_LINEAR_SET,
+        LightLightnessOpcode.LIGHT_LIGHTNESS_LINEAR_SET,
         dict(lightness=1,
              tid=34,
              transition_time=6.3,
@@ -104,7 +104,7 @@ valid_lightness = [
         id="LIGHTNESS_LINEAR_SET_invalid"),
     pytest.param(
         b'\x82\x50\x00\x00\x31\x32\x1a',
-        LightLightnessOpcode.LIGHTNESS_LINEAR_SET,
+        LightLightnessOpcode.LIGHT_LIGHTNESS_LINEAR_SET,
         dict(lightness=0,
              tid=49,
              transition_time=5,
@@ -112,7 +112,7 @@ valid_lightness = [
         id="LIGHTNESS_LINEAR_SET_with_optional"),
     pytest.param(
         b'\x82\x51\xff\x00\x31\x32\x3c',
-        LightLightnessOpcode.LIGHTNESS_LINEAR_SET_UNACKNOWLEDGED,
+        LightLightnessOpcode.LIGHT_LIGHTNESS_LINEAR_SET_UNACKNOWLEDGED,
         dict(lightness=0xff,
              tid=49,
              transition_time=5,
@@ -120,7 +120,7 @@ valid_lightness = [
         id="LIGHTNESS_LINEAR_SET_UNACKNOWLEDGED"),
     pytest.param(
         b'\x82\x52\x00\x00\xdd\xbb\x4c',
-        LightLightnessOpcode.LIGHTNESS_LINEAR_STATUS,
+        LightLightnessOpcode.LIGHT_LIGHTNESS_LINEAR_STATUS,
         dict(present_lightness=0,
              target_lightness=0xbbdd,
              remaining_time=12),
@@ -128,34 +128,34 @@ valid_lightness = [
 
     pytest.param(
         b'\x82\x53',
-        LightLightnessOpcode.LIGHTNESS_LAST_GET,
+        LightLightnessOpcode.LIGHT_LIGHTNESS_LAST_GET,
         dict(),
         id="LIGHTNESS_LAST_GET"),
     pytest.param(
         b'\x82\x54\x00\x00',
-        LightLightnessOpcode.LIGHTNESS_LAST_STATUS,
+        LightLightnessOpcode.LIGHT_LIGHTNESS_LAST_STATUS,
         dict(lightness=0),
         id="LIGHTNESS_LAST_STATUS"),
 
     pytest.param(
         b'\x82\x55',
-        LightLightnessOpcode.LIGHTNESS_DEFAULT_GET,
+        LightLightnessOpcode.LIGHT_LIGHTNESS_DEFAULT_GET,
         dict(),
         id="LIGHTNESS_DEFAULT_GET"),
     pytest.param(
         b'\x82\x56\x00\x00',
-        LightLightnessOpcode.LIGHTNESS_DEFAULT_STATUS,
+        LightLightnessOpcode.LIGHT_LIGHTNESS_DEFAULT_STATUS,
         dict(lightness=0),
         id="LIGHTNESS_STATUS"),
 
     pytest.param(
         b'\x82\x57',
-        LightLightnessOpcode.LIGHTNESS_RANGE_GET,
+        LightLightnessOpcode.LIGHT_LIGHTNESS_RANGE_GET,
         dict(),
         id="LIGHTNESS_RANGE_GET"),
     pytest.param(
         b'\x82\x58\x00\x11\x11\x88\x88',
-        LightLightnessOpcode.LIGHTNESS_RANGE_STATUS,
+        LightLightnessOpcode.LIGHT_LIGHTNESS_RANGE_STATUS,
         dict(status=StatusCode.SUCCESS,
              range_min=0x1111,
              range_max=0x8888),
@@ -167,12 +167,12 @@ valid_lightness_setup = [
     # fmt: off
     pytest.param(
         b'\x82\x59\xbb\xaa',
-        LightLightnessSetupOpcode.LIGHTNESS_DEFAULT_SET,
+        LightLightnessSetupOpcode.LIGHT_LIGHTNESS_SETUP_DEFAULT_SET,
         dict(lightness=0xaabb),
         id="LIGHTNESS_DEFAULT_SET"),
     pytest.param(
         b'\x82\x59\x01\x00',
-        LightLightnessSetupOpcode.LIGHTNESS_DEFAULT_SET,
+        LightLightnessSetupOpcode.LIGHT_LIGHTNESS_SETUP_DEFAULT_SET,
         dict(lightness=1,
              tid=34,
              transition_time=6.3,
@@ -180,19 +180,19 @@ valid_lightness_setup = [
         id="LIGHTNESS_DEFAULT_SET_invalid"),
     pytest.param(
         b'\x82\x5a\x00\x00',
-        LightLightnessSetupOpcode.LIGHTNESS_DEFAULT_SET_UNACKNOWLEDGED,
+        LightLightnessSetupOpcode.LIGHT_LIGHTNESS_SETUP_DEFAULT_SET_UNACKNOWLEDGED,
         dict(lightness=0),
         id="LIGHTNESS_SET_UNACKNOWLEDGED"),
 
     pytest.param(
         b'\x82\x5b\x11\x00\xff\xee',
-        LightLightnessSetupOpcode.LIGHTNESS_RANGE_SET,
+        LightLightnessSetupOpcode.LIGHT_LIGHTNESS_SETUP_RANGE_SET,
         dict(range_min=0x0011,
              range_max=0xeeff),
         id="LIGHTNESS_RANGE_SET"),
     pytest.param(
         b'\x82\x5c\xcd\xab\x34\x12',
-        LightLightnessSetupOpcode.LIGHTNESS_RANGE_SET_UNACKNOWLEDGED,
+        LightLightnessSetupOpcode.LIGHT_LIGHTNESS_SETUP_RANGE_SET_UNACKNOWLEDGED,
         dict(range_min=0xabcd,
              range_max=0x1234),
         id="LIGHTNESS_RANGE_SET_UNACKNOWLEDGED"),
@@ -204,12 +204,12 @@ valid_ctl = [
     # fmt: off
     pytest.param(
         b'\x82\x5d',
-        LightCTLOpcode.CTL_GET,
+        LightCTLOpcode.LIGHT_CTL_GET,
         dict(),
         id="CTL_GET"),
     pytest.param(
         b'\x82\x5e\xbb\xaa\xdd\xcc\xff\xee\x01',
-        LightCTLOpcode.CTL_SET,
+        LightCTLOpcode.LIGHT_CTL_SET,
         dict(ctl_lightness=0xaabb,
              ctl_temperature=0xccdd,
              ctl_delta_uv=0xeeff,
@@ -217,7 +217,7 @@ valid_ctl = [
         id="CTL_SET"),
     pytest.param(
         b'\x82\x5e\xbb\xaa\xdd\xcc\xff\xee\x22',
-        LightCTLOpcode.CTL_SET,
+        LightCTLOpcode.LIGHT_CTL_SET,
         dict(ctl_lightness=0xaabb,
              ctl_temperature=0xccdd,
              ctl_delta_uv=0xeeff,
@@ -227,7 +227,7 @@ valid_ctl = [
         id="CTL_SET_invalid"),
     pytest.param(
         b'\x82\x5e\xbb\xaa\xdd\xcc\xff\xee\x22\x32\x3c',
-        LightCTLOpcode.CTL_SET,
+        LightCTLOpcode.LIGHT_CTL_SET,
         dict(ctl_lightness=0xaabb,
              ctl_temperature=0xccdd,
              ctl_delta_uv=0xeeff,
@@ -237,7 +237,7 @@ valid_ctl = [
         id="CTL_SET_with_optional"),
     pytest.param(
         b'\x82\x5f\x11\x11\x22\x22\x33\x33\x22\x32\x3c',
-        LightCTLOpcode.CTL_SET_UNACKNOWLEDGED,
+        LightCTLOpcode.LIGHT_CTL_SET_UNACKNOWLEDGED,
         dict(ctl_lightness=0x1111,
              ctl_temperature=0x2222,
              ctl_delta_uv=0x3333,
@@ -247,13 +247,13 @@ valid_ctl = [
         id="CTL_SET_UNACKNOWLEDGED"),
     pytest.param(
         b'\x82\x60\x11\x11\x22\x22',
-        LightCTLOpcode.CTL_STATUS,
+        LightCTLOpcode.LIGHT_CTL_STATUS,
         dict(present_ctl_lightness=0x1111,
              present_ctl_temperature=0x2222),
         id="CTL_STATUS"),
     pytest.param(
         b'\x82\x60\x11\x11\x22\x22\x33\x33\x44\x44\x0f',
-        LightCTLOpcode.CTL_STATUS,
+        LightCTLOpcode.LIGHT_CTL_STATUS,
         dict(present_ctl_lightness=0x1111,
              present_ctl_temperature=0x2222,
              target_ctl_lightness=0x3333,
@@ -263,19 +263,19 @@ valid_ctl = [
 
     pytest.param(
         b'\x82\x61',
-        LightCTLOpcode.CTL_TEMPERATURE_GET,
+        LightCTLOpcode.LIGHT_CTL_TEMPERATURE_GET,
         dict(),
         id="CTL_TEMPERATURE_GET"),
     pytest.param(
         b'\x82\x64\xdd\xcc\xff\xee\x0a',
-        LightCTLOpcode.CTL_TEMPERATURE_SET,
+        LightCTLOpcode.LIGHT_CTL_TEMPERATURE_SET,
         dict(ctl_temperature=0xccdd,
              ctl_delta_uv=0xeeff,
              tid=10),
         id="CTL_TEMPERATURE_SET"),
     pytest.param(
         b'\x82\x64\xdd\xcc\xff\xee\x22\x32\x14',
-        LightCTLOpcode.CTL_TEMPERATURE_SET,
+        LightCTLOpcode.LIGHT_CTL_TEMPERATURE_SET,
         dict(ctl_temperature=0xccdd,
              ctl_delta_uv=0xeeff,
              tid=34,
@@ -284,7 +284,7 @@ valid_ctl = [
         id="CTL_TEMPERATURE_SET_with_optional"),
     pytest.param(
         b'\x82\x65\x22\x22\x33\x33\xff\x32\x3c',
-        LightCTLOpcode.CTL_TEMPERATURE_SET_UNACKNOWLEDGED,
+        LightCTLOpcode.LIGHT_CTL_TEMPERATURE_SET_UNACKNOWLEDGED,
         dict(ctl_temperature=0x2222,
              ctl_delta_uv=0x3333,
              tid=0xff,
@@ -293,13 +293,13 @@ valid_ctl = [
         id="CTL_TEMPERATURE_SET_UNACKNOWLEDGED"),
     pytest.param(
         b'\x82\x66\x22\x22\xff\xff',
-        LightCTLOpcode.CTL_TEMPERATURE_STATUS,
+        LightCTLOpcode.LIGHT_CTL_TEMPERATURE_STATUS,
         dict(present_ctl_temperature=0x2222,
              present_ctl_delta_uv=0xffff),
         id="CTL_TEMPERATURE_STATUS"),
     pytest.param(
         b'\x82\x66\x11\x11\x22\x22\x33\x33\x44\x44\x0f',
-        LightCTLOpcode.CTL_TEMPERATURE_STATUS,
+        LightCTLOpcode.LIGHT_CTL_TEMPERATURE_STATUS,
         dict(present_ctl_temperature=0x1111,
              present_ctl_delta_uv=0x2222,
              target_ctl_temperature=0x3333,
@@ -309,12 +309,12 @@ valid_ctl = [
 
     pytest.param(
         b'\x82\x62',
-        LightCTLOpcode.CTL_TEMPERATURE_RANGE_GET,
+        LightCTLOpcode.LIGHT_CTL_TEMPERATURE_RANGE_GET,
         dict(),
         id="CTL_TEMPERATURE_RANGE_GET"),
     pytest.param(
         b'\x82\x63\x00\xdd\xcc\xff\xee',
-        LightCTLOpcode.CTL_TEMPERATURE_RANGE_STATUS,
+        LightCTLOpcode.LIGHT_CTL_TEMPERATURE_RANGE_STATUS,
         dict(status=StatusCode.SUCCESS,
              range_min=0xccdd,
              range_max=0xeeff),
@@ -322,12 +322,12 @@ valid_ctl = [
 
     pytest.param(
         b'\x82\x67',
-        LightCTLOpcode.CTL_TEMPERATURE_DEFAULT_GET,
+        LightCTLOpcode.LIGHT_CTL_TEMPERATURE_DEFAULT_GET,
         dict(),
         id="CTL_TEMPERATURE_DEFAULT_GET"),
     pytest.param(
         b'\x82\x68\xdd\xcc\xff\xee\x11\x11',
-        LightCTLOpcode.CTL_TEMPERATURE_DEFAULT_STATUS,
+        LightCTLOpcode.LIGHT_CTL_TEMPERATURE_DEFAULT_STATUS,
         dict(ctl_lightness=0xccdd,
              ctl_temperature=0xeeff,
              ctl_delta_uv=0x1111),
@@ -339,14 +339,14 @@ valid_ctl_setup = [
     # fmt: off
     pytest.param(
         b'\x82\x69\xdd\xcc\xff\xee\x11\x11',
-        LightCTLSetupOpcode.CTL_TEMPERATURE_DEFAULT_SET,
+        LightCTLSetupOpcode.LIGHT_CTL_SETUP_TEMPERATURE_DEFAULT_SET,
         dict(ctl_lightness=0xccdd,
              ctl_temperature=0xeeff,
              ctl_delta_uv=0x1111),
         id="CTL_TEMPERATURE_DEFAULT_SET"),
     pytest.param(
         b'\x82\x6a\xdd\xcc\xff\xee\x11\x11',
-        LightCTLSetupOpcode.CTL_TEMPERATURE_DEFAULT_SET_UNACKNOWLEDGED,
+        LightCTLSetupOpcode.LIGHT_CTL_SETUP_TEMPERATURE_DEFAULT_SET_UNACKNOWLEDGED,
         dict(ctl_lightness=0xccdd,
              ctl_temperature=0xeeff,
              ctl_delta_uv=0x1111),
@@ -354,13 +354,13 @@ valid_ctl_setup = [
 
     pytest.param(
         b'\x82\x6b\xdd\xcc\xff\xee',
-        LightCTLSetupOpcode.CTL_TEMPERATURE_RANGE_SET,
+        LightCTLSetupOpcode.LIGHT_CTL_SETUP_TEMPERATURE_RANGE_SET,
         dict(range_min=0xccdd,
              range_max=0xeeff),
         id="CTL_TEMPERATURE_RANGE_SET"),
     pytest.param(
         b'\x82\x6c\x11\x11\x22\x22',
-        LightCTLSetupOpcode.CTL_TEMPERATURE_RANGE_SET_UNACKNOWLEDGED,
+        LightCTLSetupOpcode.LIGHT_CTL_SETUP_TEMPERATURE_RANGE_SET_UNACKNOWLEDGED,
         dict(range_min=0x1111,
              range_max=0x2222),
         id="CTL_TEMPERATURE_RANGE_SET_UNACKNOWLEDGED"),
